==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/lang/en.utf8/pieforms.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['element.bytes.bytes'] = 'Bytes';
$string['element.bytes.kilobytes'] = 'Kilobytes';
$string['element.bytes.megabytes'] = 'Megabytes';
$string['element.bytes.gigabytes'] = 'Gigabytes';
$string['element.bytes.invalidvalue'] = 'Value must be a number';

$string['element.calendar.invalidvalue'] = 'Invalid date/time specified';

$string['element.date.or'] = 'or';
$string['element.date.monthnames'] = 'January,February,March,April,May,June,July,August,September,October,November,December';
$string['element.date.notspecified'] = 'Not specified';

$string['element.expiry.days'] = 'Days';
$string['element.expiry.weeks'] = 'Weeks';
$string['element.expiry.months'] = 'Months';
$string['element.expiry.years'] = 'Years';
$string['element.expiry.noenddate'] = 'No end date';

$string['rule.before.before'] = 'This can not be after the field "%s"';

$string['rule.email.email'] = 'E-mail address is invalid';

$string['rule.integer.integer'] = 'The field must be an integer';

$string['rule.maxlength.maxlength'] = 'This field must be at most %d characters long';

$string['rule.minlength.minlength'] = 'This field must be at least %d characters long';

$string['rule.minvalue.minvalue'] = 'This value can not be smaller than %d';

$string['rule.regex.regex'] = 'This field is not in valid form';

$string['rule.required.required'] = 'This field is required';

$string['rule.validateoptions.validateoptions'] = 'The option "%s" is invalid';

$string['rule.maxvalue.maxvalue'] = 'This value can not be larger than %d';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/lang/en.utf8/pieforms.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['element.bytes.bytes'] = 'Bytes';
$string['element.bytes.kilobytes'] = 'Kilobytes';
$string['element.bytes.megabytes'] = 'Megabytes';
$string['element.bytes.gigabytes'] = 'Gigabytes';
$string['element.bytes.invalidvalue'] = 'Value must be a number';

$string['element.calendar.invalidvalue'] = 'Invalid date/time specified';

$string['element.date.or'] = 'or';
$string['element.date.monthnames'] = 'January,February,March,April,May,June,July,August,September,October,November,December';
$string['element.date.notspecified'] = 'Not specified';

$string['element.expiry.days'] = 'Days';
$string['element.expiry.weeks'] = 'Weeks';
$string['element.expiry.months'] = 'Months';
$string['element.expiry.years'] = 'Years';
$string['element.expiry.noenddate'] = 'No end date';

$string['rule.before.before'] = 'This cannot be after the field "%s"';

$string['rule.email.email'] = 'Email address is invalid';

$string['rule.integer.integer'] = 'The field must be an integer';

$string['rule.maxlength.maxlength'] = 'This field must be at most %d characters long';

$string['rule.minlength.minlength'] = 'This field must be at least %d characters long';

$string['rule.minvalue.minvalue'] = 'This value cannot be smaller than %d';

$string['rule.regex.regex'] = 'This field is not in valid form';

$string['rule.required.required'] = 'This field is required';

$string['rule.validateoptions.validateoptions'] = 'The option "%s" is invalid';

$string['rule.maxvalue.maxvalue'] = 'This value cannot be larger than %d';
